@@ -119,7 +119,7 @@ class WorkflowCollectionEngagement(CreatedModifiedAbstractModel):
         )
 
         for step in all_collection_steps:
-            pprint(vars(step), "\n")
+            print(vars(step), "\n")
 
         # Special case to prevent crash when collection has no steps.
         if not all_collection_steps:
@@ -151,7 +151,7 @@ class WorkflowCollectionEngagement(CreatedModifiedAbstractModel):
         )
 
         for collection in all_collection_workflows:
-            pprint("Collection Member", vars(collection), "\n")
+            print("Collection Member", vars(collection), "\n")
 
         all_engagement_details: QuerySet[
             WorkflowCollectionEngagementDetail
@@ -292,6 +292,9 @@ class WorkflowCollectionEngagement(CreatedModifiedAbstractModel):
 
                 Go through steps in index order sort of like Rocky had previously.
                 """
+
+                print("Last Step", vars(previous_step))
+
                 first_step_of_next_workflow = (
                     all_collection_steps.filter(
                         workflow_order__gt=previous_step.workflow_order
@@ -300,6 +303,8 @@ class WorkflowCollectionEngagement(CreatedModifiedAbstractModel):
                     .first()
                 )
 
+                print("First Step of Next Workflow", first_step_of_next_workflow)
+
                 if first_step_of_next_workflow:
                     next_step = first_step_of_next_workflow
                     next_workflow = first_step_of_next_workflow.workflow
