@@ -11,14 +11,12 @@ def get_user_input_type_helper(request):
     """
     Get the example_specification of a given WorkflowStepUserInputType
     """
-    if request.GET.get('uuid', None):
-        uuid = request.GET.get('uuid', None)
+    if request.GET.get("uuid", None):
+        uuid = request.GET.get("uuid", None)
         user_input_type = WorkflowStepUserInputType.objects.get(id=uuid)
-        payload = {
-            "specification": user_input_type.example_specification
-        }
+        payload = {"specification": user_input_type.example_specification}
 
     else:
         payload = {}
 
-    return HttpResponse(json.dumps(payload))
\ No newline at end of file
+    return HttpResponse(json.dumps(payload))
